/**
 * 
 */
package com.liferay.portal.tools;

import junit.framework.TestCase;

/**
 * @author linhart1
 *
 */
public class CSSBuilderTest extends TestCase {

	/* (non-Javadoc)
	 * @see junit.framework.TestCase#setUp()
	 */
	@Override
	protected void setUp() throws Exception {
		// TODO Auto-generated method stub
		super.setUp();
	}

	/**
	 * Test method for {@link com.liferay.portal.tools.CSSBuilder#replaceImports(java.lang.String, java.lang.String)}.
	 */
	public void testReplaceImports() {
		assertNotNull(new CSSBuilder("V:/tool/Liferay/cssbuilder5/run/develop/css/css",
									 "V:/tool/Liferay/cssbuilder5/run/develop/css/css/everything_unpacked.css"));
	}

	/**
	 * Test method for {@link com.liferay.portal.tools.CSSBuilder#replaceUrlRelativePaths(String, String)}.
	 */
	public void testReplaceUrlRelativePaths() {
		assertEquals("Wrong resolution A", "abcd url() efg", CSSBuilder.replaceUrlRelativePaths("abcd url() efg", "my/relative/path"));
		assertEquals("Wrong resolution B", "url(\"\")", CSSBuilder.replaceUrlRelativePaths("url(\"\")", "my/relative/path"));
		assertEquals("Wrong resolution C0", "url(http://aaa.bbb.ccc/ddd)", CSSBuilder.replaceUrlRelativePaths("url(http://aaa.bbb.ccc/ddd)", "my/relative/path"));
		assertEquals("Wrong resolution C1", "url(ftp://aaa.bbb.ccc/ddd)", CSSBuilder.replaceUrlRelativePaths("url(ftp://aaa.bbb.ccc/ddd)", "my/relative/path"));
		assertEquals("Wrong resolution C2", "url(file://aaa.bbb.ccc/ddd)", CSSBuilder.replaceUrlRelativePaths("url(file://aaa.bbb.ccc/ddd)", "my/relative/path"));
		assertEquals("Wrong resolution C3", "url(xxx://aaa.bbb.ccc/ddd)", CSSBuilder.replaceUrlRelativePaths("url(xxx://aaa.bbb.ccc/ddd)", "my/relative/path"));
		assertEquals("Wrong resolution D", "url(\"http://aaa.bbb.ccc/ddd\")", CSSBuilder.replaceUrlRelativePaths("url(\"http://aaa.bbb.ccc/ddd\")", "my/relative/path"));
		assertEquals("Wrong resolution E", "url(my/relative/path/aaa/bbb)", CSSBuilder.replaceUrlRelativePaths("url(aaa/bbb)", "my/relative/path"));
		assertEquals("Wrong resolution F", "url(my/relative/path/./aaa/bbb)", CSSBuilder.replaceUrlRelativePaths("url(./aaa/bbb)", "my/relative/path"));
		assertEquals("Wrong resolution G", "  url(my/relative/path/../aaa/bbb)   ", CSSBuilder.replaceUrlRelativePaths("  url(../aaa/bbb)   ", "my/relative/path"));
		assertEquals("Wrong resolution H0a", "abcde url(my/relative/path/../../aaa/bbb) fghij ", CSSBuilder.replaceUrlRelativePaths("abcde url(../../aaa/bbb) fghij ", "my/relative/path"));
		assertEquals("Wrong resolution H0b", "abcde url(my/relative/path/..\\..\\aaa\\bbb) fghij", CSSBuilder.replaceUrlRelativePaths("abcde url(..\\..\\aaa\\bbb) fghij", "my/relative/path"));
		assertEquals("Wrong resolution H1", "abcde url( \"my/relative/path/../../aaa/bbb\" ) fghij", CSSBuilder.replaceUrlRelativePaths("abcde url( \"../../aaa/bbb\" ) fghij", "my/relative/path"));
		assertEquals("Wrong resolution H2", "abcde url(\"my/relative/path/../../aaa/bbb\") fghij", CSSBuilder.replaceUrlRelativePaths("abcde url(\"../../aaa/bbb\") fghij", "my/relative/path"));
		assertEquals("Wrong resolution H3", "ab c de url(my/relative/path/../../aaa/bbb) fgh < {  } > ij", CSSBuilder.replaceUrlRelativePaths("ab c de url(../../aaa/bbb) fgh < {  } > ij", "my/relative/path"));
		assertEquals("Wrong resolution H4", "ab myurl c de url(my/relative/path/../../aaa/bbb) fgh < {  } > ij", CSSBuilder.replaceUrlRelativePaths("ab myurl c de url(../../aaa/bbb) fgh < {  } > ij", "my/relative/path"));
		assertEquals("Wrong resolution I", "url( /aaa/bbb)", CSSBuilder.replaceUrlRelativePaths("url( /aaa/bbb)", "my/relative/path"));
		assertEquals("Wrong resolution J", "url(\\aaa/bbb )", CSSBuilder.replaceUrlRelativePaths("url(\\aaa/bbb )", "my/relative/path"));
		assertEquals("Wrong resolution K", "url(C:\\aaa\\bbb )", CSSBuilder.replaceUrlRelativePaths("url(C:\\aaa\\bbb )", "my/relative/path"));
		assertEquals("Wrong resolution L", "url(\"C:\\aaa\\bbb\" )", CSSBuilder.replaceUrlRelativePaths("url(\"C:\\aaa\\bbb\" )", "my/relative/path"));
		
	}
	
	/**
	 * Test method for {@link com.liferay.portal.tools.CSSBuilder#resolveUrlStringFromBegin(java.lang.String)}.
	 */
	public void testResolveUrlStringFromBegin() {
		assertEquals("Wrong resolution for '()' A", "myurl", CSSBuilder.resolveUrlStringFromBegin("(myurl)"));
		assertEquals("Wrong resolution for '()' B", "myurl", CSSBuilder.resolveUrlStringFromBegin("  (  myurl )  "));
		assertEquals("Wrong resolution for '()' C", "myurl", CSSBuilder.resolveUrlStringFromBegin("  (myurl)  "));
		assertEquals("Wrong resolution for '()' D", "myurl", CSSBuilder.resolveUrlStringFromBegin("(  myurl  )"));
		assertEquals("Wrong resolution for '\"\"' E", "myurl", CSSBuilder.resolveUrlStringFromBegin("\"myurl\""));
		assertEquals("Wrong resolution for '\"\"' F", "myurl", CSSBuilder.resolveUrlStringFromBegin("\"   myurl  \""));
		assertEquals("Wrong resolution for '(\"\")' G", "myurl", CSSBuilder.resolveUrlStringFromBegin("(\"myurl\")"));
		assertEquals("Wrong resolution for '(\"\")' H", "myurl", CSSBuilder.resolveUrlStringFromBegin("(\"myurl\")"));
		assertEquals("Wrong resolution for '()' I", "myurl", CSSBuilder.resolveUrlStringFromBegin("url(myurl)"));
		assertEquals("Wrong resolution for '()' J", "myurl", CSSBuilder.resolveUrlStringFromBegin("URL(myurl)"));
		assertEquals("Wrong resolution for '()' K", "myurl", CSSBuilder.resolveUrlStringFromBegin("url (myurl)"));
		assertEquals("Wrong resolution for '()' L", "myurl", CSSBuilder.resolveUrlStringFromBegin("url (\"myurl\")"));
		assertEquals("Wrong resolution for '()' M", "myurl", CSSBuilder.resolveUrlStringFromBegin("url ( myurl )"));
		assertEquals("Wrong resolution for '()' N", "myurl", CSSBuilder.resolveUrlStringFromBegin("url ( \" myurl \" )"));
		assertEquals("Wrong resolution for '()' O", "myurl", CSSBuilder.resolveUrlStringFromBegin("url ( \" myurl\")"));
	}

	/**
	 * Test method for {@link com.liferay.portal.tools.CSSBuilder#resolveUrlStringFromIndex(java.lang.String, int, java.lang.String)}.
	 */
//	public void testResolveUrlStringFromIndex() {
//		fail("Not yet implemented");
//	}

}
